# coding: utf-8

"""
    CustomerManagementService

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self

class AccountFinancialStatus(str, Enum):
    PROPOSED = 'Proposed'

    PENDINGCREDITCHECK = 'PendingCreditCheck'

    CLEARFINANCIALSTATUS = 'ClearFinancialStatus'

    SOLDTOONLY = 'SoldToOnly'

    CREDITWARNING = 'CreditWarning'

    HOLD = 'Hold'

    WRITEOFF = 'WriteOff'

    TAXONHOLD = 'TaxOnHold'

    USERHOLD = 'UserHold'

	
    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of AccountFinancialStatus from a JSON string"""
        return cls(json.loads(json_str))


