# coding: utf-8

"""
    ReportingService

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self

class SearchInsightPerformanceReportColumn(str, Enum):
    ACCOUNTNAME = 'AccountName'

    ACCOUNTNUMBER = 'AccountNumber'

    ACCOUNTID = 'AccountId'

    TIMEPERIOD = 'TimePeriod'

    CAMPAIGNNAME = 'CampaignName'

    CAMPAIGNID = 'CampaignId'

    ADGROUPNAME = 'AdGroupName'

    ADGROUPID = 'AdGroupId'

    CAMPAIGNSTATUS = 'CampaignStatus'

    IMPRESSIONS = 'Impressions'

    CLICKS = 'Clicks'

    CTR = 'Ctr'

    SPEND = 'Spend'

    SEARCHQUERY = 'SearchQuery'

    CONVERSIONS = 'Conversions'

    CONVERSIONRATE = 'ConversionRate'

    REVENUE = 'Revenue'

    RETURNONADSPEND = 'ReturnOnAdSpend'

    REVENUEPERCONVERSION = 'RevenuePerConversion'

    ACCOUNTSTATUS = 'AccountStatus'

    ADGROUPSTATUS = 'AdGroupStatus'

    CUSTOMERID = 'CustomerId'

    CUSTOMERNAME = 'CustomerName'

    ASSETGROUPID = 'AssetGroupId'

    ASSETGROUPNAME = 'AssetGroupName'

    ASSETGROUPSTATUS = 'AssetGroupStatus'

    SEARCHCATEGORY = 'SearchCategory'

    SEARCHVOLUME = 'SearchVolume'

	
    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of SearchInsightPerformanceReportColumn from a JSON string"""
        return cls(json.loads(json_str))


