# coding: utf-8

"""
    ReportingService

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self

class TravelQueryInsightReportColumn(str, Enum):
    SEARCHQUERY = 'SearchQuery'

    COUNTRY = 'Country'

    REGION = 'Region'

    METROAREA = 'MetroArea'

    CITY = 'City'

    POSTALCODE = 'PostalCode'

    L1VERTICAL = 'L1Vertical'

    L2VERTICAL = 'L2Vertical'

    L3VERTICAL = 'L3Vertical'

    POSCOUNTRY = 'POSCountry'

    POSREGION = 'POSRegion'

    POSCITY = 'POSCity'

    BRANDIMPRESSIONS = 'BrandImpressions'

    BRANDCLICKS = 'BrandClicks'

    BRANDSPEND = 'BrandSpend'

    MSAIMPRESSIONS = 'MSAImpressions'

    MSACLICKS = 'MSAClicks'

    MSASPEND = 'MSASpend'

	
    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of TravelQueryInsightReportColumn from a JSON string"""
        return cls(json.loads(json_str))


